********************************************************************************
* MULTILEVEL ANALYSIS OF INDIVIDUAL HETEROGENEITY AND DISCRIMINATORY ACCURACY 
* (MAIHDA) – USING MULTILEVEL MODELS TO STUDY INTERSECTIONALITY
********************************************************************************
* Andy Bell
* Sheffield Methods Institute, University of Sheffield
*
* Adapted for Stata by George Leckie
* Centre for Multilevel Modelling, University of Bristol
********************************************************************************

* Change the current working directory to do-file and dataset location
* From Stata File menu: Change working directory...
* Or, edit and uncomment the following command:
* cd "TYPE THE DIRECTORY PATH WHERE THE STATA DO-FILE AND DATA ARE SAVED HERE"

* Set version number
version 18.5



********************************************************************************
**# Initial software setup, and data loading
********************************************************************************
* Load the dataset
use "TutorialData.dta", clear



********************************************************************************
**# Generating the stratum ID
********************************************************************************

* Generate the stratum ID
generate stratum = 10000 * sex + 1000 * race + 100 * education + 10 * income ///
  + 1 * age

* Tabulate the strata
tabulate stratum

* Generate the stratum size
bysort stratum: generate strataN = _N



********************************************************************************
**# Descriptive statistics
********************************************************************************

* Tabulate individuals by sex
tabulate sex

* Tabulate individuals by race
tabulate race

* Tabulate individuals by education
tabulate education

* Tabulate individuals by income
tabulate income

* Tabulate individuals by age
tabulate age

* Summarize HbA1c
summarize HbA1c

* Plot a histogram of HbA1c
histogram HbA1c



********************************************************************************
**# Running our two MAIHDA models
********************************************************************************

* Fit the model
mixed HbA1c || stratum:, reml

* Store the model results
estimates store model1A

* Predict the stratum mean value of HbA1c
predict m1Am, fitted

* Fit the model
mixed HbA1c i.sex i.race i.education i.income i.age || stratum:, reml

* Store the model results
estimates store model1B

* Predict the stratum mean value of HbA1c
predict m1Bm, fitted

* Predict the stratum random effects and their standard errors
predict m1Bu, reffects reses(m1Buse)

* Collapse the data down to one record per stratum
collapse (mean) HbA1c, ///
	by(stratum sex race education income age strataN m1Am m1Bm m1Bu m1Buse)



********************************************************************************
**# Model analysis
********************************************************************************

* Create a table of estimation results
etable, estimates(model1A model1B)



********************************************************************************
**# Looking at specific strata
********************************************************************************

* Rank the predicted stratum means
egen m1Bmrank = rank(m1Bm)

* Plot a caterpillar plot of the predicted stratum means
serrbar m1Bm m1Buse m1Bmrank, scale(1.96) yline(0)

* Sort the data by m1Bmrank
sort m1Bmrank

* List the six strata with the lowest predicted stratum means 
list in 1/6, separator(0)

* List the six strata with the highest predicted stratum means
list in -6/l, separator(0)

* Rank the predicted stratum random interaction effects
egen m1Burank = rank(m1Bu)

* Plot a caterpillar plot of the predicted stratum random interaction effects
serrbar m1Bu m1Buse m1Burank, scale(1.96) yline(0)

* Generate a binary indicator for whether each predicted stratum random 
* interaction effect is statistically significant
generate sig = (m1Bu + 1.96 * m1Buse < 0 | m1Bu - 1.96 * m1Buse > 0)

* Keep those strata which show statistically significant predicted stratum 
* random interaction effects
keep if sig == 1

* Rank the predicted stratum random interaction effects
egen m1Buranknew = rank(m1Bu)

* Plot a caterpillar plot of the statistically significant predicted stratum 
* random interaction effects
serrbar m1Bu m1Buse m1Buranknew, scale(1.96) yline(0)

* Plot a caterpillar plot of the statistically significant predicted stratum 
* random interaction effects with stratum IDs superimposed
serrbar m1Bu m1Buse m1Buranknew, scale(1.96) yline(0) ///
	addplot((scatter m1Bu m1Buranknew, ///
	mlabel(stratum) mlabposition(12) mlabgap(*20))) legend(off)



********************************************************************************
exit